BoxedMontyMultiplier

Struct BoxedMontyMultiplier 

pub struct BoxedMontyMultiplier<'a> {
    product: BoxedUint,
    modulus: &'a BoxedUint,
    mod_neg_inv: Limb,
}
Montgomery multiplier with a pre-allocated internal buffer to avoid additional allocations.

Fields

product: BoxedUintmodulus: &'a BoxedUintmod_neg_inv: Limb

Implementations

Source

impl<'a> BoxedMontyMultiplier<'a>

pub(super) fn new(modulus: &'a BoxedUint, mod_neg_inv: Limb) -> Self

Create a new Montgomery multiplier.

pub(super) fn mul_assign(&mut self, a: &mut BoxedUint, b: &BoxedUint)

Perform a Montgomery multiplication, assigning a fully reduced result to a.

pub(super) fn square_assign(&mut self, a: &mut BoxedUint)

Perform a squaring using Montgomery multiplication, assigning a fully reduced result to a.

pub(super) fn mul_amm_assign(&mut self, a: &mut BoxedUint, b: &BoxedUint)

Perform an “Almost Montgomery Multiplication”, assigning the product to a.

NOTE: the resulting output will be reduced to the bit length of the modulus, but not fully reduced and may exceed the modulus. A final reduction is required to ensure AMM results are fully reduced, and should not be exposed outside the internals of this crate.

pub(super) fn square_amm_assign(&mut self, a: &mut BoxedUint)

Perform a squaring using “Almost Montgomery Multiplication”, assigning the result to a.

NOTE: the resulting output will be reduced to the bit length of the modulus, but not fully reduced and may exceed the modulus. A final reduction is required to ensure AMM results are fully reduced, and should not be exposed outside the internals of this crate.